package com.rizzoweb.alarm;

/**
 * This class represents a scheduled task that is triggered by an
 * alarm.  The task is added to an AlarmManager to schedule it so
 * that when its alarm fires its handleAlarm() method is called.  It
 * can also be cancelled through cancel() to unschedule it by removing
 * it from the manager.
 */
public abstract class AlarmTask implements AlarmListener {

	private AlarmSchedule schedule;
	private AlarmManager manager;

	/**
	 * Adds my AlarmSchedule to the given manager.  If I am later cancelled,
	 * my AlarmSchedule is removed from this manager.
	 */
	public void addTo(AlarmManager aManager) {

		aManager.addAlarm(getSchedule());
		this.manager = aManager;
	}

	/**
	 * Cancels me by removing my AlarmSchedule from the alarm manager.
	 */
	public void cancel() {

		if (manager != null) {
			manager.removeAlarm(getSchedule());
		}
	}

	protected AlarmTask(AlarmSchedule aSchedule) {

		this.schedule = aSchedule;
		aSchedule.setListener(this);
	}

	/**
	 * Simple accessor to my AlarmSchedule.
	 */
	protected AlarmSchedule getSchedule() {
		return schedule;
	}
}
